@@ -1,7 +1,8 @@
-import os, random, sys, time, csv, pickle, re, pkg_resources, 
-import Pmw, mido
+import os, random, sys, time, csv, pickle, re, pkg_resources
+import mido
 os.environ['PYGAME_HIDE_SUPPORT_PROMPT']="hide"
-from tkinter import StringVar, DoubleVar, Tk, Label, Entry, Button, OptionMenu, Checkbutton, Message, Menu, IntVar, Scale, HORIZONTAL, simpledialog, messagebox, Toplevel
+from tkinter import StringVar, DoubleVar, Tk, Label, Entry, Button, OptionMenu, \
+Checkbutton, Message, Menu, IntVar, Scale, HORIZONTAL, simpledialog, messagebox, Toplevel
 from tkinter.ttk import Progressbar, Separator, Combobox
 from tkinter import filedialog as fd 
 import tkinter.font as font
@@ -59,7 +60,7 @@ def run(display=True):
 	Main command to run GUI or CLI
 	'''
 	root=GUI(display=display)
-	sys.ps1 = '♫ '
+	sys.ps1='♫ '
 	if display:
 		root.mainloop()
 	else:
@@ -74,18 +75,15 @@ class GUI(Tk):
 		the GUI 'hidden'
 		'''
 		self.display=display
-		self.tooltips_on=False
 		self.sf_path=os.path.join(os.path.dirname(os.path.abspath(__file__)),'anthem_soundfonts')
 		if not os.path.isdir(self.sf_path):
 			print('Initializing soundfont library...')
 			os.mkdir(self.sf_path)
-			gdd.download_file_from_google_drive(file_id=sound_font,dest_path=os.path.join(os.path.join(os.path.dirname(os.path.abspath(__file__)),'anthem_soundfonts'),'font.sf2'),showsize=True)
+			gdd.download_file_from_google_drive(file_id=sound_font,dest_path=\
+				os.path.join(os.path.join(os.path.dirname(os.path.abspath(__file__)),'anthem_soundfonts'),'font.sf2'),showsize=True)
 		if self.display:
 			Tk.__init__(self)
 			self.default_font=font.nametofont("TkDefaultFont")
-			if tooltipson:
-				Pmw.initialise()
-				self.balloon=Pmw.Balloon(self)
 			self.initGUI()
 	
 	def quit(self,event=None):
@@ -133,10 +131,9 @@ class GUI(Tk):
 		'''
 		Saves config file.
 		'''
-		if self.check_data():
-			file_out=os.path.join(self.cfg['save_path'],self.cfg['file_out'])+'_cfg.p'
-			pickle.dump(self.cfg,open(file_out, "wb"))
-			self.message(f'cfg file saved to {file_out}')
+		file_out=os.path.join(self.cfg['save_path'],self.cfg['file_out'])+'_cfg.p'
+		pickle.dump(self.cfg,open(file_out, "wb"))
+		self.message(f'cfg file saved to {file_out}')
 	
 	def load_data(self,filein=None):
 		'''
@@ -144,16 +141,32 @@ class GUI(Tk):
 		'''
 		if filein is None:
 			filein=uiopen(title='Select .mat file for import',filetypes=[('.mat files','*.mat')])
-		if filein == '.':
+		if filein=='.':
 			return
-		self.data=loadmat(filein)
-		try:
-			self.data['W_shape']=self.data['W'].shape
-			self.data['W']=self.data['W'].reshape(self.data['W'].shape[0]*self.data['W'].shape[1],self.data['W'].shape[2])
-			self.data['fr']=float(self.data['fr'])
+		data={}
+		data_unk=loadmat(filein)
+		for k in data_unk.keys():
+			if k in ('__header__', '__version__', '__globals__'):
+				continue
+			elif len(data_unk[k])==1:
+				data['fr']=float(data_unk[k])
+			elif data_unk[k].ndim==2:
+				data['H']=data_unk[k]
+			elif data_unk[k].ndim==3:
+				data['W']=data_unk[k]
+		if ('H' in data and 'W' in data) and data['H'].shape[0] != data['W'].shape[-1] :
+			self.message('Error: Inner dimensions of {} x {} do not match!')
+			return
+		if 'H' in data:
+			if 'W' in data:
+				data['W_shape']=data['W'].shape
+				data['W']=data['W'].reshape(data['W'].shape[0]*data['W'].shape[1],data['W'].shape[2])
+			if 'fr' not in data:
+				data['fr']=data['H'].shape[1]/60 # Forces length to be 1 minute!
+			self.data=data
 			if not self.display:
 				return self
-		except:
+		else:
 			self.message('Error: .mat file incompatible. Please select a .mat file with three variables: W (3D), H (2D), and fr (1-element float)')
 
 	def load_GUI(self):
@@ -161,13 +174,16 @@ class GUI(Tk):
 		GUI-addons for load_data. Prompts user with filedialog, assigns defaults and sets GUI fields. 
 		'''
 		filein=uiopen(title='Select .mat file for import',filetypes=[('.mat files','*.mat')])
-		if filein == '.':
+		if filein=='.':
 			return
 		self.load_data(filein)
+		if not hasattr(self,'data'):
+			return
 		self.data['H_pp']=self.data['H']
 		self.data['H_fp']=self.data['H']
-		self.data['W_pp']=self.data['W']
 		self.fr.set(self.data['fr'])
+		if 'W' in self.data:
+			self.data['W_pp']=self.data['W']
 		self.file_in.set(os.path.splitext(os.path.split(filein)[1])[0])
 
 		# Set some defaults
@@ -176,10 +192,9 @@ class GUI(Tk):
 		Hstr='H' # for whatever reason, can't double nest quotations in an f-string :/
 		self.brightness.set(f'{float(f"{np.mean(self.data[Hstr])+np.std(self.data[Hstr]):.3g}"):g}')
 		self.threshold.set(f'{float(f"{np.mean(self.data[Hstr])+np.std(self.data[Hstr]):.3g}"):g}')
-		self.Wshow_arr=list(range(len(self.data['H'])))
-		self.process_H_W()
+		self.comps_to_show_arr=list(range(len(self.data['H'])))
 		self.init_plots()
-		self.refresh_GUI()
+		self.process_H_W()
 	
 	def load_config(self,filein=None):
 		'''
@@ -187,7 +202,7 @@ class GUI(Tk):
 		'''
 		if filein is None:
 			filein=uiopen(title='Select pickle file for import',filetypes=[('pickle file','*.p'),('pickle file','*.pkl'),('pickle file','*.pickle')])
-		if filein == '.':
+		if filein=='.':
 			return
 		with open(filein, "rb") as f:
 			self.cfg=pickle.load(f)
@@ -202,80 +217,69 @@ class GUI(Tk):
 				return self
 
 	def refresh_GUI(self,event=None):
-		if not self.check_data():
-			return
-		self.init_plots()
+		#self.init_plots()
+		if 'W_pp' in self.data:
+			if self.frameslider.get() > len(self.data['H_pp'].T): # This (usually) occurs when the user crops the dataset
+				self.frameslider.set(1)
+			self.frameslider['to']=int(len(self.data['H_pp'].T)-1)
+			self.imWH=self.Wax1.imshow((self.data['W_pp']@np.diag(self.data['H_pp'][:,self.frameslider.get()])@\
+				self.cmap[:,:-1]*(255/self.cfg['brightness'])).reshape(self.data['W_shape'][0],self.data['W_shape'][1],3)\
+				.clip(min=0,max=255).astype('uint8'))
+			self.imW=self.Wax2.imshow((self.data['W_pp']@self.cmap[:,:-1]*255/np.max(self.data['W_pp'])).\
+				reshape(self.data['W_shape'][0],self.data['W_shape'][1],3).clip(min=0,max=255).astype('uint8'))
+			self.imW.axes.set_aspect('equal')
+			self.imWH.axes.set_aspect('equal')
+			self.canvas_W.draw()
+			self.refresh_slider([])
 
-		# Update slider (Need to move the command)
-		if self.frameslider.get() > len(self.data['H_pp'].T): # This (usually) occurs when the user crops the dataset
-			self.frameslider.set(1)
-		self.frameslider['to']=int(len(self.data['H_pp'].T)-1)
+		if 'H_pp' in self.data:
+			Hstd=self.data['H_pp'].std()*3
+			if self.offsetH.get():
+				tmpH=self.data['H_pp'].T - repmat([w*Hstd for w in list(range(len(self.comps_to_show_arr)))],len(self.data['H_pp'].T),1)
+			else:
+				tmpH=self.data['H_pp'].T
 
-		Hstd=self.data['H_pp'].std()*3
-		if self.offsetH.get():
-			tmpH=self.data['H_pp'].T - repmat([w*Hstd for w in list(range(len(self.Wshow_arr)))],len(self.data['H_pp'].T),1)
-		else:
-			tmpH=self.data['H_pp'].T
+			self.Hax1.cla()
+			self.Hax1.plot(tmpH,linewidth=.5)
+			for i,j in enumerate(self.Hax1.lines):
+				j.set_color(self.cmap[i])
+			if not self.offsetH.get():
+				thresh_line=self.Hax1.plot(np.ones((len(self.data['H_pp'].T,)))*self.cfg['threshold'],linestyle='dashed',color='0',linewidth=1)
+				zero_line=self.Hax1.plot(np.zeros((len(self.data['H_pp'].T,))),linestyle='dashed',color='.5',linewidth=1)
+				self.legend=self.Hax1.legend((thresh_line[0],), ('Threshold',))
+			self.Hax1.set_xlim(0, len(self.data['H_pp'].T))
+			self.Hax1.set_ylim(np.min(tmpH), np.max(tmpH))
+			if self.offsetH.get():
+				self.Hax1.set(ylabel='Component #')
+			else:
+				self.Hax1.set(ylabel='Magnitude')
 
-		self.H_plot=self.Hax1.plot(tmpH,linewidth=.5)
-		for i,j in enumerate(self.Hax1.lines):
-			j.set_color(self.cmap[i])
-		if not self.offsetH.get():
-			thresh_line=self.Hax1.plot(np.ones((len(self.data['H_pp'].T,)))*self.cfg['threshold'],linestyle='dashed',color='0',linewidth=1)
-			zero_line=self.Hax1.plot(np.zeros((len(self.data['H_pp'].T,))),linestyle='dashed',color='.5',linewidth=1)
-			self.legend=self.Hax1.legend((thresh_line[0],), ('Threshold',))
-			#self.legend=self.Hax1.legend((thresh_line[0],zero_line[0]), ('Threshold','Baseline'))
+			if self.audio_analog.get():
+				if len(self.data['H_pp'])>16:
+					self.audio_analog.set(0)
+					self.Hax2.imshow(self.data['H_fp'],interpolation='none',cmap=plt.get_cmap('gray'))
+					self.message('Error: Analog audio is currently limited to 16 components.')
+				else:
+					# I do not understand why I have to do it this way
+					tmp=self.Hax2.imshow(self.data['H_pp'],interpolation='none',cmap=plt.get_cmap('gray'))
+					tmp.set_clim(0, np.max(self.data['H_pp']))
+			else:
+				self.Hax2.imshow(self.data['H_fp'],interpolation='none',cmap=plt.get_cmap('gray'))
 
-		if self.cfg['audio_analog']:
-			self.H_p_plot=self.Hax2.imshow(self.data['H_pp'],interpolation='none',cmap=plt.get_cmap('gray'))
-			self.H_p_plot.set_clim(0, np.max(self.data['H_pp']))
-		else:
-			self.H_p_plot=self.Hax2.imshow(self.data['H_fp'],interpolation='none',cmap=plt.get_cmap('gray'))
+			self.Hax2.xaxis.set_major_formatter(tkr.FuncFormatter(lambda x, pos: '{:.2g}'.format(x/self.cfg['fr'])))
 
-		self.Hax2.xaxis.set_major_formatter(tkr.FuncFormatter(lambda x, pos: '{:.2g}'.format(x/self.cfg['fr'])))
-		self.Hax2.set(xlabel='time (sec)',ylabel='Component #')
+			if len(self.comps_to_show_arr) > 12:
+				yticks=np.arange(4,len(self.data['H_pp']),5)
+				yticklabels=np.arange(4,len(self.data['H_pp']),5)
+			else:
+				yticks=np.arange(0,len(self.data['H_pp']),1)
+				yticklabels=np.arange(0,len(self.data['H_pp']),1)
 
-		self.Hax1.set_xlim(0, len(self.data['H_pp'].T))
-		self.Hax1.set_ylim(np.min(tmpH), np.max(tmpH))
-		if self.offsetH.get():
-			self.Hax1.set(ylabel='Component #')
-		else:
-			self.Hax1.set(ylabel='Magnitude')
-
-		self.Hax1.spines['left'].set_visible(False)
-		self.Hax1.spines['top'].set_visible(False)
-		self.Hax1.spines['bottom'].set_visible(False)
-		self.Hax1.spines['right'].set_visible(False)
-		self.Hax1.yaxis.tick_right()
-		self.Hax1.yaxis.set_label_position("right")
-		self.Hax1.tick_params(axis='x',which='both',bottom=False, top=False, labelbottom=False, right=False)
-
-		if len(self.Wshow_arr) > 12:
-			yticks=np.arange(4,len(self.data['H_pp']),5)
-			yticklabels=np.arange(4,len(self.data['H_pp']),5)
-		else:
-			yticks=np.arange(0,len(self.data['H_pp']),1)
-			yticklabels=np.arange(0,len(self.data['H_pp']),1)
-
-		if self.offsetH.get():
-			self.Hax1.set(yticks=-yticks*Hstd,yticklabels=yticklabels)
-		self.Hax2.set(yticks=yticks,yticklabels=yticklabels)
-		self.Hax2.spines['left'].set_visible(False)
-		self.Hax2.spines['top'].set_visible(False)
-		self.Hax2.spines['bottom'].set_visible(False)
-		self.Hax2.spines['right'].set_visible(False)
-		self.Hax2.yaxis.tick_right()
-		self.Hax2.yaxis.set_label_position("right")
-		self.imWH=self.Wax1.imshow((self.data['W_pp']@np.diag(self.data['H_pp'][:,self.frameslider.get()])@self.cmap[:,:-1]*(255/self.cfg['brightness'])).reshape(self.data['W_shape'][0],self.data['W_shape'][1],3).clip(min=0,max=255).astype('uint8'))
-		self.imW=self.Wax2.imshow((self.data['W_pp']@self.cmap[:,:-1]*255/np.max(self.data['W_pp'])).reshape(self.data['W_shape'][0],self.data['W_shape'][1],3).clip(min=0,max=255).astype('uint8'))
-		
-		self.H_p_plot.axes.set_aspect('auto')
-		self.imW.axes.set_aspect('equal')
-		self.imWH.axes.set_aspect('equal')
-		self.canvas_H.draw()
-		self.canvas_W.draw()
-		self.refresh_slider([])
-		self.message('')
+			if self.offsetH.get():
+				self.Hax1.set(yticks=-yticks*Hstd,yticklabels=yticklabels)
+			self.Hax2.set(yticks=yticks,yticklabels=yticklabels)
+			self.Hax2.axes.set_aspect('auto')
+			self.canvas_H.draw()
 
 	def process_H_W(self):
 		'''
@@ -285,22 +289,23 @@ class GUI(Tk):
 		'''
 		if self.display:
 			self.self_to_cfg()
-			self.status['text']='Updating...'
+			self.message('Updating...')
 			self.update()
-		if self.cfg['Wshow'] == 'all':
-			self.Wshow_arr=list(range(len(self.data['H'])))
+		if self.cfg['comps_to_show']=='all':
+			self.comps_to_show_arr=list(range(len(self.data['H'])))
 		# regex expression which lazily checks for a bracketed expression containing numbers, colons and commas.
-		elif re.match('^\[[0-9,: ]*\]$',self.cfg['Wshow']) is not None:
+		elif re.match('^\[[0-9,: ]*\]$',self.cfg['comps_to_show']) is not None:
 			# This is a magic function which transforms bracketed string arrays to actual numpy arrays.
 			# Example: '[1,3,5:8]' --> array([1,3,5,6,7])
-			self.Wshow_arr=eval('np.r_'+self.cfg['Wshow']) 
+			self.comps_to_show_arr=eval('np.r_'+self.cfg['comps_to_show']) 
 		else:
 			self.message('For \'components to show\', please input indices with commas and colons enclosed by square brackets, or \'all\' for all components.')
 			return
 		
-		self.data['H_pp']=self.data['H'][self.Wshow_arr,int(len(self.data['H'].T)*self.cfg['start_percent']/100):int(len(self.data['H'].T)*self.cfg['end_percent']/100)]
+		self.data['H_pp']=self.data['H'][self.comps_to_show_arr,int(len(self.data['H'].T)*self.cfg['start_percent']/100):int(len(self.data['H'].T)*self.cfg['end_percent']/100)]
 		self.data['H_pp']=self.data['H_pp']+self.cfg['baseline']
-		self.data['W_pp']=self.data['W'][:,self.Wshow_arr]
+		if 'W' in self.data:
+			self.data['W_pp']=self.data['W'][:,self.comps_to_show_arr]
 		
 		# make_keys()
 		self.keys,i=[],0
@@ -322,15 +327,15 @@ class GUI(Tk):
 		self.data['H_pp'][self.data['H_pp'] < 0]=0
 		self.data['H_pp'][:,-1]=0
 		self.data['H_pp'][:,0]=0
-		self.nd = []
+		self.nd=[]
 		for i in range(nchan):
 			H_rs=interp1d(t1,self.data['H_pp'][i,:])(t2)
 			H_b=H_rs.copy()
 			H_b[H_b<self.cfg['threshold']]=0
 			H_b[H_b>=self.cfg['threshold']]=1
 			TC=np.diff(H_b)
-			st=np.argwhere(TC == 1)
-			en=np.argwhere(TC == -1)
+			st=np.argwhere(TC==1)
+			en=np.argwhere(TC==-1)
 			st=np.ndarray.flatten(st).tolist()
 			en=np.ndarray.flatten(en).tolist()
 			for j in range(len(st)):
@@ -339,24 +344,19 @@ class GUI(Tk):
 				# Type, time, note, velocity
 				self.nd.append(['note_on',st[j],self.keys[i],int(mag * 127 / Hmax)])
 				self.nd.append(['note_off',en[j],self.keys[i],int(mag * 127 / Hmax)])
-			self.nd = sorted(self.nd, key=lambda x: x[1])
+			self.nd=sorted(self.nd, key=lambda x: x[1])
 		# Colormap
 		cmap=getattr(cmaps,self.cfg['cmapchoice'])
 		self.cmap=cmap(np.linspace(0,1,len(self.data['H_pp'])))
 		if self.display:
 			self.refresh_GUI()
-		self.message('')
 
 	def refresh_slider(self,event):
 		'''
 		
 		'''
-		#try: # May want to use hasattr() here instead
 		self.imWH.set_data((self.data['W_pp']@np.diag(self.data['H_pp'][:,self.frameslider.get()])@self.cmap[:,:-1]*(255/self.cfg['brightness'])).reshape(self.data['W_shape'][0],self.data['W_shape'][1],3).clip(min=0,max=255).astype('uint8'))
 		self.canvas_W.draw()
-		#self.H_vline.set_xdata([self.frameslider.get(), self.frameslider.get()])
-		#self.H_vline.set_ydata(self.Hax1.get_ylim())
-		#self.canvas_H.draw()
 
 	def preview_notes(self):
 		'''
@@ -371,9 +371,8 @@ class GUI(Tk):
 			pre_init(fs, -16, 2, 1024)
 			init()
 			set_num_channels(128) # We will never need more than 128...
-		
-		mid = mido.MidiFile()
-		track = mido.MidiTrack()
+		mid=mido.MidiFile()
+		track=mido.MidiTrack()
 		mid.tracks.append(track)
 		mid.ticks_per_beat=1000
 		track.append(mido.MetaMessage('set_tempo', tempo=int(1e6)))
@@ -395,11 +394,15 @@ class GUI(Tk):
 			self.imW=self.Wax2.imshow((Wtmp[:,None]@cmaptmp[None,:]*255/np.max(self.data['W_pp'])).reshape(self.data['W_shape'][0],self.data['W_shape'][1],3).clip(min=0,max=255).astype('uint8'))
 			self.canvas_W.draw()
 			self.update()
-			if i == 0:
+			if i==0:
 				music.play(0)
 			time.sleep(.5-np.min(((time.time()-t),.5)))
-		os.remove(fn_midi)
-		os.remove(fn_wav)
+		time.sleep(1)
+		try:
+			os.remove(fn_midi)
+			os.remove(fn_wav)
+		except:
+			pass
 		self.refresh_GUI()
 		
 	def write_audio(self):
@@ -412,8 +415,8 @@ class GUI(Tk):
 		fn_midi=os.path.join(self.cfg['save_path'],self.cfg['file_out'])+'.mid'
 		fn_wav=os.path.join(self.cfg['save_path'],self.cfg['file_out'])+'.wav'
 		fn_font=os.path.join(os.path.dirname(os.path.abspath(__file__)),'anthem_soundfonts','font.sf2')
-		mid = mido.MidiFile()
-		track = mido.MidiTrack()
+		mid=mido.MidiFile()
+		track=mido.MidiTrack()
 		mid.tracks.append(track)
 		mid.ticks_per_beat=1000
 		track.append(mido.MetaMessage('set_tempo', tempo=int(1e6)))
@@ -432,7 +435,7 @@ class GUI(Tk):
 			t2=np.linspace(0,len(self.data['H_pp'].T)/self.cfg['fr'],ns)
 			nchan=len(self.data['H_pp'])
 			Hmax=np.max(self.data['H_pp'])
-			H_rs = np.zeros((nchan,ns))
+			H_rs=np.zeros((nchan,ns))
 			ticks=int(mid.ticks_per_beat/upsample)
 			for i in range(nchan):
 				H_rs[i,:]=interp1d(t1,self.data['H_pp'][i,:])(t2)
@@ -455,12 +458,13 @@ class GUI(Tk):
 
 	def write_video(self):
 		'''
-		Writes video file using self.data['H_pp'] using ffmpeg. 
+		Writes video file using self.data['H_pp'] and self.data['W_pp'] using ffmpeg. 
 		We avoid using opencv because it is very slow in a conda environment
 		http://zulko.github.io/blog/2013/09/27/read-and-write-video-frames-in-python-using-ffmpeg/
 		'''
 		if not self.check_data():
 			return
+
 		self.process_H_W()
 		fn_vid=os.path.join(self.cfg['save_path'],self.cfg['file_out'])+'.mp4'
 		v_shape=self.data['W_shape'][::-1][1:] # Reverse because ffmpeg does hxw
@@ -495,23 +499,21 @@ class GUI(Tk):
 		'''
 		Merges video and audio with ffmpeg
 		'''
-		if self.check_data():
-			fn=os.path.join(self.cfg['save_path'],self.cfg['file_out'])
-			cmd='ffmpeg -hide_banner -loglevel warning -y -i {} -i {} -c:v copy -c:a aac {}'.format(fn+'.mp4',fn+'.wav',fn+'_AV.mp4')
-			os.system(cmd)
-			self.message(f'A/V file written to {self.cfg["save_path"]}')
-			return self
+		fn=os.path.join(self.cfg['save_path'],self.cfg['file_out'])
+		cmd='ffmpeg -hide_banner -loglevel warning -y -i {} -i {} -c:v copy -c:a aac {}'.format(fn+'.mp4',fn+'.wav',fn+'_AV.mp4')
+		os.system(cmd)
+		self.message(f'A/V file written to {self.cfg["save_path"]}')
+		return self
 	
 	def write_AV(self):
 		'''
 		Runs full write and merge
 		'''
-		if self.check_data():
-			self.write_video()
-			self.write_audio()
-			self.merge()
-			if not self.display:
-				return self
+		self.write_video()
+		self.write_audio()
+		self.merge()
+		if not self.display:
+			return self
 
 	def cleanup(self):
 		'''
@@ -558,7 +560,7 @@ class GUI(Tk):
 		self.scale_type=init_entry('Maj. 7 (4/oct)')
 		self.key=init_entry('C')
 		self.sound_preset=init_entry('Piano')
-		self.Wshow=init_entry('all')
+		self.comps_to_show=init_entry('all')
 		self.cmapchoice=init_entry('jet')
 		
 		# Labels
@@ -582,7 +584,8 @@ class GUI(Tk):
 		Label(text='Audio format').grid(row=6, column=5, sticky='E')
 
 		# Messages
-		self.status=Message(text='Welcome to pyanthem v{}!'.format(pkg_resources.require("pyanthem")[0].version),bg='white',fg='black',width=450)
+		self.status=Message(text='Welcome to pyanthem v{}!'.\
+			format(pkg_resources.require("pyanthem")[0].version),bg='white',fg='black',width=450)
 		self.status.grid(row=9, column=2, columnspan=5, sticky='NESW')
 		self.status['anchor']='nw'
 
@@ -628,7 +631,7 @@ class GUI(Tk):
 
 		# Checkbox
 		self.audio_analog=IntVar()
-		self.audio_analog.set(1)
+		self.audio_analog.set(0)
 		Checkbutton(self, text="Analog",command=self.process_H_W,variable=self.audio_analog).grid(row=7, column=6,columnspan=1)
 
 		# Menu bar
@@ -670,66 +673,78 @@ class GUI(Tk):
 		self.offsetH=IntVar()
 		self.offsetH.set(1)
 
-		# frameslider
-		self.frameslider=Scale(self, from_=0, to=1, orient=HORIZONTAL)
-		self.frameslider['command']=self.refresh_slider
-
 		# Bind shortcuts
 		self.bind_all("<Control-q>", self.quit)
 		self.bind_all("<Control-a>", lambda:[self.process_H_W(),self.refresh_GUI()])
 
-		# tooltips
-		if self.tooltips_on:
-			self.balloon.bind(self.octave_add_menu,'Sets which octave notes begin at. \nHigher values produce higher pitched notes.')
-			self.balloon.bind(self.scale_type_menu,'Scale type for audio - higher notes/oct are recommended for high component datasets.')
-			self.balloon.bind(self.key_menu,'Musical key for audio')
-			self.balloon.bind(self.cmapchooser,'Color map for visualization.')
-			self.balloon.bind(self.threshold_entry,'Minimum value H must reach before rendering an audible note.')
-			self.balloon.bind(self.update_button,'Redraws plots using current config options.')
-
 	def init_plots(self):
 		'''
 		Initializes the plot areas. Is called every time update_GUI() is called.
 		'''
 		# H
-		self.figH=plt.Figure(figsize=(6,6), dpi=100, tight_layout=True)
-		self.Hax1=self.figH.add_subplot(211)
-		self.Hax2=self.figH.add_subplot(212)
-		self.Hax1.set_title('Temporal Data (H)')
-		self.Hax2.set_title('Audio Preview (H\')')
-		self.canvas_H=FigureCanvasTkAgg(self.figH, master=self)
-		self.canvas_H.get_tk_widget().grid(row=1,column=7,rowspan=29,columnspan=10)
-		bg=self.status.winfo_rgb(self['bg'])
-		self.figH.set_facecolor([(x>>8)/255 for x in bg])
-		#self.canvas_H.draw()
-
-		# Checkbox
-		Checkbutton(self, text="Offset H",command=self.refresh_GUI,variable=self.offsetH).grid(row=1,rowspan=1,column=16)
-
-		# W
-		self.figW=plt.Figure(figsize=(6,3), dpi=100, constrained_layout=True)
-		self.Wax1=self.figW.add_subplot(121)
-		self.Wax2=self.figW.add_subplot(122)
-		self.Wax1.set_title('Video Preview')
-		self.Wax2.set_title('Spatial Data (W)')
-		self.Wax1.axis('off')
-		self.Wax2.axis('off')
-		self.canvas_W=FigureCanvasTkAgg(self.figW, master=self)
-		self.canvas_W.get_tk_widget().grid(row=11,column=1,rowspan=19,columnspan=6)
-		self.figW.set_facecolor([(x>>8)/255 for x in bg])
-		#self.canvas_W.draw()
+		if 'H_pp' in self.data:
+			self.figH=plt.Figure(figsize=(6,6), dpi=100, tight_layout=True)
+			self.Hax1=self.figH.add_subplot(211)
+			self.Hax2=self.figH.add_subplot(212)
+			self.Hax1.set_title('Temporal Data (H)')
+			self.Hax2.set_title('Audio Preview (H\')')
+			self.canvas_H=FigureCanvasTkAgg(self.figH, master=self)
+			self.canvas_H.get_tk_widget().grid(row=1,column=7,rowspan=30,columnspan=10)
+			bg=self.status.winfo_rgb(self['bg'])
+			self.figH.set_facecolor([(x>>8)/255 for x in bg])
+			self.Hax1.spines['left'].set_visible(False)
+			self.Hax1.spines['top'].set_visible(False)
+			self.Hax1.spines['bottom'].set_visible(False)
+			self.Hax1.spines['right'].set_visible(False)
+			self.Hax1.yaxis.tick_right()
+			self.Hax1.yaxis.set_label_position("right")
+			self.Hax1.tick_params(axis='x',which='both',bottom=False, top=False, labelbottom=False, right=False)
+			self.Hax2.set(xlabel='time (sec)',ylabel='Component #')
+			self.Hax2.spines['left'].set_visible(False)
+			self.Hax2.spines['top'].set_visible(False)
+			self.Hax2.spines['bottom'].set_visible(False)
+			self.Hax2.spines['right'].set_visible(False)
+			self.Hax2.yaxis.tick_right()
+			self.Hax2.yaxis.set_label_position("right")
+			# Checkbox
+			Checkbutton(self, text="Offset H",command=self.refresh_GUI,variable=self.offsetH).grid(row=1,rowspan=1,column=16)
 		
-		# Frameslider
-		self.frameslider.grid(row=30, column=1, columnspan=3,sticky='EW')
+		try: 
+			# If user previously loaded dataset with W, clear those 
+			# plots and remove associated GUI elements.
+			self.figW.clear()
+			self.canvas_W.draw()
+			self.frameslider.grid_forget()
+			self.comps_to_show_label.grid_forget()
+			self.comps_to_show_entry.grid_forget()
+		except:
+			pass
+
+		if 'W_pp' in self.data:
+			self.figW=plt.Figure(figsize=(6,3), dpi=100, constrained_layout=True)
+			self.Wax1=self.figW.add_subplot(121)
+			self.Wax2=self.figW.add_subplot(122)
+			self.Wax1.set_title('Video Preview')
+			self.Wax2.set_title('Spatial Data (W)')
+			self.Wax1.axis('off')
+			self.Wax2.axis('off')
+			self.canvas_W=FigureCanvasTkAgg(self.figW, master=self)
+			self.canvas_W.get_tk_widget().grid(row=11,column=1,rowspan=19,columnspan=6)
+			self.figW.set_facecolor([(x>>8)/255 for x in bg])
+			
+			# Frameslider
+			# frameslider
+			self.frameslider=Scale(self, from_=1, to=2, orient=HORIZONTAL)
+			self.frameslider.set(1)
+			self.frameslider['command']=self.refresh_slider
+			self.frameslider.grid(row=30, column=1, columnspan=3,sticky='EW')
+			
+		# comps_to_show
+		self.comps_to_show_label=Label(text='Components:')
+		self.comps_to_show_label.grid(row=30, column=5, columnspan=1, sticky='E')
+		self.comps_to_show_entry=Entry(textvariable=self.comps_to_show,width=15,justify='center')
+		self.comps_to_show_entry.grid(row=30, column=6, columnspan=1,sticky='W')
 		
-		# Wshow
-		Label(text='Components to show:').grid(row=30, column=3, columnspan=3, sticky='E')
-		Entry(textvariable=self.Wshow,width=15,justify='center').grid(row=30, column=5, columnspan=2,sticky='E')
-
-		# tooltips
-		if self.tooltips_on:
-			self.balloon.bind(self.offsetH, '(Checked) Display lines one seperate y-axes\n(Unchecked) Display all lines with the same y-axis')
-
 	def process_raw(self,file_in=None,n_clusters=None,frame_rate=None,save=False):
 		'''
 		Decomposes raw dataset. Can be used in two ways: as a part of the 
@@ -738,7 +753,7 @@ class GUI(Tk):
 		'''
 		if filein is None:
 			filein=uiopen(title='Select .mat file for import',filetypes=[('.mat files','*.mat')])
-		if filein == '.':
+		if filein=='.':
 			return
 		dh, var=loadmat(file_in),whosmat(file_in)
 		data=dh[var[0][0]]
@@ -785,7 +800,7 @@ class GUI(Tk):
 		self.data['H']=H
 		self.data['W']=W.reshape(sh[0],sh[1],n_clusters)
 		self.data['W_shape']=self.data['W'].shape
-		if frame_rate == []:
+		if frame_rate==[]:
 			self.data['fr']=10
 			print('No fr given. Defaulting to 10')
 		else:
@@ -822,7 +837,7 @@ class GUI(Tk):
 	def help(self):
 		print('To load a dataset:\npyanthem.load_data()\n\nTo load a cfg file:\npyanthem.load_config()\n\nTo write video:\npyanthem.write_video()\n\nTo write audio:\npyanthem.write_audio()')
 
-if __name__ == "__main__":
+if __name__=="__main__":
 	run()
 
 # self\.([a-z_]{1,14})\.get\(\)
